<?php
/**
 * Plugin Name:       UnfoldWP Import Companion
 * Plugin URI:        https://wordpress.org/plugins/unfoldwp-import-companion/
 * Description:       Manages Demo import data for UnfoldWP
 * Version:           1.1.1
 * Author:            UnfoldWP
 * Author URI:        https://unfoldwp.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       unfoldwp-import-companion
 * Domain Path:       /languages
 * Requires at least: 5.6
 * Requires PHP: 5.2
 * Tested up to: 6.0
 * 
 *
 * @package           Unfoldwp_Import_Companion
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );  // prevent direct access

// Current plugin version.
define( 'UF_IC_VERSION', '1.1.1' );

if ( ! defined( 'UF_IC_URL' ) ) {
	define( 'UF_IC_URL', plugin_dir_url( __FILE__ ) );
}

if ( ! defined( 'UF_IC_DIR' ) ) {
	define( 'UF_IC_DIR', plugin_dir_path( __FILE__ ) );
}

if ( ! defined( 'UF_IC_INC' ) ) {
	define( 'UF_IC_INC', UF_IC_DIR . 'includes/' );
}

if ( ! function_exists( 'unfold_import_install' ) ) {
	/**
	 * Performs pre-flight checks, and gives green light for plugin bootstrap
	 *
	 * @return void
	 * @since 1.0.0
	 */
	function unfold_import_install() {

		if ( ! function_exists( 'is_plugin_active' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		load_plugin_textdomain( 'unfoldwp-import-companion', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

		if ( ! class_exists( 'OCDI_Plugin' ) ) {
			if(is_multisite()){
				add_action( 'network_admin_notices', 'unfold_install_ocdi_admin_notice' );
			}else{
				add_action( 'admin_notices', 'unfold_install_ocdi_admin_notice' );
			}
		} else {
			unfold_import_init();
		}
	}
}
add_action( 'plugins_loaded', 'unfold_import_install' );

if ( ! function_exists( 'unfold_install_ocdi_admin_notice' ) ) {
	/**
	 * Shows admin notice if plugin is activated without OCDI
	 *
	 * @return void
	 * @since 1.0.0
	 */
	function unfold_install_ocdi_admin_notice() {
		?>
		<div class="error">
			<p><?php echo esc_html( 'UnfoldWP Import Companion is not effective. Please install & activate One click Demo Import plugin first.', 'unfoldwp-import-companion' ); ?></p>
		</div>
		<?php
	}
}

if ( ! function_exists( 'unfold_import_init' ) ) {
	/**
	 * 
	 * Sets proper Import file for themes
	 *
	 * @return void
	 * @since 1.0.0
	 */
	function unfold_import_init() {

		// Only execute on the admin side
		if(is_admin()){

			// Base url of the repository
			$base_url = 'https://raw.githubusercontent.com/unfoldwp/free-themes-demo-content/master';

			// Get the json file to populate proper demo setup settings
			$config_file = $base_url."/init.json";
			
			$data = wp_remote_get($config_file );

			// Only execute if our config is loaded properly
			if ( is_array( $data ) && ! is_wp_error( $data ) ) {

				$data = wp_remote_retrieve_body( $data );
				$data = json_decode($data,true);

				// Get Current Theme
				$current_theme = wp_get_theme();
				$theme_template = get_template();

				// Check if the theme is compatible
				if( in_array( $theme_template, $data['themes'] ) ){

					// Add some useful fields to the array
					$data = array_merge(
						array(
							'base_url' => $base_url,
							'theme_name' => $current_theme->get( 'Name' ),
							'theme_template' => $theme_template,
						),
						$data
					);
					
					// define a global that can be used inside hooks
					define("UNFOLD_DEMO_CONFIG", $data);

					add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
					add_filter( 'ocdi/plugin_page_title', 'unfold_import_ocdi_title' );
					add_filter( 'ocdi/plugin_intro_text', 'unfold_import_ocdi_intro' );

					add_filter( 'ocdi/plugin_page_setup', 'unfold_import_ocdi_setup' );
					add_filter( 'pt-ocdi/import_files', 'unfold_import_config' );
					add_action( 'pt-ocdi/after_import', 'unfold_after_import_setup' );
				}
			}
		}
	}
}

if( !function_exists('unfold_import_ocdi_title') ){
	/**
	 * OCDI Remove Title
	 *
	 * @since 1.0.0
	 */
	function unfold_import_ocdi_title( $plugin_title ) {
		$plugin_title = "";
		return $plugin_title;
	}
}

if( !function_exists('unfold_import_ocdi_intro') ){
	/**
	 * OCDI Remove Intro text
	 *
	 * @since 1.0.0
	 */
	function unfold_import_ocdi_intro( $plugin_intro_text ) {
		$plugin_intro_text = "";
		return $plugin_intro_text;
	}
}

if( !function_exists('unfold_import_ocdi_setup') ){
	/**
	 * OCDI Setup
	 *
	 * @since 1.0.2
	 */
	function unfold_import_ocdi_setup( $default_settings ) {

		// Access our global config
		$data = UNFOLD_DEMO_CONFIG;

		$default_settings['parent_slug'] = 'themes.php';
		$default_settings['page_title']  = $data['theme_name'].' Demo Import';
		$default_settings['menu_title']  = __( 'Import Demo Data' , 'unfoldwp-import-companion' );
		$default_settings['capability']  = 'import';
		$default_settings['menu_slug']   = $data['theme_template'].'-demo-import';

		return $default_settings;
	}
}

if( !function_exists('unfold_import_config') ){
	/**
	 * OCDI Config
	 *
	 * @since 1.0.2
	 */
	function unfold_import_config(){

		// Access our global config
		$data = UNFOLD_DEMO_CONFIG;

		$output = array();

		$theme_template = str_replace("-", "_", $data['theme_template']);
		if( isset( $data['config'][$theme_template] ) ){

			$demo_content = $data['config'][$theme_template]['demo_content'];
			if( $demo_content && is_array($demo_content) ){

				foreach( $demo_content as $demo => $content ){
					$output[] = array(
						'import_file_name'             => $content['name'],
						'import_file_url'              => $data['base_url'].'/'.$data['theme_template'].'/demo-content/'.$demo.'/content.xml',
						'import_widget_file_url'       => $data['base_url'].'/'.$data['theme_template'].'/demo-content/'.$demo.'/widgets.wie',
						'import_customizer_file_url'   => $data['base_url'].'/'.$data['theme_template'].'/demo-content/'.$demo.'/customizer.dat',
						'import_preview_image_url'     => $data['base_url'].'/'.$data['theme_template'].'/demo-content/'.$demo.'/screenshot.png',
						'preview_url'                  => $content['preview_url'],
					);
				}

			}
		}

		return $output;
	}
}

if( !function_exists('unfold_after_import_setup') ){
	/**
	 * OCDI After Import
	 *
	 * @since 1.0.2
	 */
	function unfold_after_import_setup(){

		// Access our global config
		$data = UNFOLD_DEMO_CONFIG;

		// Assign front page and posts page (blog page) if any.
		$front_page_id = null;
		$blog_page_id  = null;
	
		$front_page = get_page_by_title( 'Homepage' );
	
		if ( $front_page ) {
			if ( is_array( $front_page ) ) {
				$first_page = array_shift( $front_page );
				$front_page_id = $first_page->ID;
			} else {
				$front_page_id = $front_page->ID;
			}
		}
	
		$blog_page = get_page_by_title( 'Blog' );
	
		if ( $blog_page ) {
			if ( is_array( $blog_page ) ) {
				$first_page = array_shift( $blog_page );
				$blog_page_id = $first_page->ID;
			} else {
				$blog_page_id = $blog_page->ID;
			}
		}
	
		if ( $front_page_id && $blog_page_id ) {
			update_option( 'show_on_front', 'page' );
			update_option( 'page_on_front', $front_page_id );
			update_option( 'page_for_posts', $blog_page_id );
		}
	
		// Assign navigation menu locations.
		$menu_location_details = array(
			'primary-menu' => 'primary-menu',
			'footer-menu' => 'footer-menu',
			'top-menu' => 'top-menu',
			'social-menu' => 'social-menu',
		);
	
		if ( ! empty( $menu_location_details ) ) {
			$navigation_settings = array();
			$current_navigation_menus = wp_get_nav_menus();
			if ( ! empty( $current_navigation_menus ) && ! is_wp_error( $current_navigation_menus ) ) {
				foreach ( $current_navigation_menus as $menu ) {
					if ( in_array( $menu->slug, $menu_location_details) ) {
						$navigation_settings[ $menu->slug ] = $menu->term_id;
					}
				}
			}
			set_theme_mod( 'nav_menu_locations', $navigation_settings );
		}
	}
}

if( !function_exists('unfold_import_enqueue_styles') ){
	/**
	 * Admin Style & Scripts
	 *
	 * @since 1.0.0
	*/
	function unfold_import_enqueue_styles(){
		wp_enqueue_style( 'unfoldwp-import-companion', UF_IC_URL . 'admin/css/unfoldwp-import-companion-admin.css', array(), UF_IC_VERSION, 'all' );
	}
}
add_action( 'admin_enqueue_scripts', 'unfold_import_enqueue_styles' );